pub enum MovementStatus {
Pending,
Successful,
Failed,
Canceled,
}Variants
Pending
The default status of a new Movement. Should be treated as in-progress.
Successful
The Movement has completed successfully.
Failed
The Movement failed to complete due to an error. Note; this does not mean that VTXOs or user funds didn’t change, old VTXOs may be consumed and new ones produced.
Canceled
A Movement was canceled, either by the protocol (e.g., lightning payments) or by the user.