pub struct OnchainBalance {
pub total: Amount,
pub trusted_spendable: Amount,
pub immature: Amount,
pub trusted_pending: Amount,
pub untrusted_pending: Amount,
pub confirmed: Amount,
}Fields
total: AmountAll of them combined.
trusted_spendable: AmountGet sum of trusted_pending and confirmed coins.
This is the balance you can spend right now that shouldn’t get canceled via another party double spending it.
immature: AmountAll coinbase outputs not yet matured
trusted_pending: AmountUnconfirmed UTXOs generated by a wallet tx
untrusted_pending: AmountUnconfirmed UTXOs received from an external wallet
confirmed: AmountConfirmed and immediately spendable balance