pub struct ArkInfo {Show 16 fields
pub network: Network,
pub server_pubkey: PublicKey,
pub mailbox_pubkey: PublicKey,
pub round_interval: Duration,
pub nb_round_nonces: usize,
pub vtxo_exit_delta: BlockDelta,
pub vtxo_expiry_delta: BlockDelta,
pub htlc_send_expiry_delta: BlockDelta,
pub htlc_expiry_delta: BlockDelta,
pub max_vtxo_amount: Option<Amount>,
pub required_board_confirmations: usize,
pub max_user_invoice_cltv_delta: u16,
pub min_board_amount: Amount,
pub offboard_feerate_sat_per_kvb: u64,
pub ln_receive_anti_dos_required: bool,
pub fees: FeeSchedule,
}Fields
network: NetworkThe bitcoin network the server operates on
server_pubkey: PublicKeyThe Ark server pubkey
mailbox_pubkey: PublicKeyThe pubkey used for blinding unified mailbox IDs
round_interval: DurationThe interval between each round
nb_round_nonces: usizeNumber of nonces per round
vtxo_exit_delta: BlockDeltaDelta between exit confirmation and coins becoming spendable
vtxo_expiry_delta: BlockDeltaExpiration delta of the VTXO
htlc_send_expiry_delta: BlockDeltaThe number of blocks after which an HTLC-send VTXO expires once granted.
htlc_expiry_delta: BlockDeltaThe number of blocks to keep between Lightning and Ark HTLCs expiries
max_vtxo_amount: Option<Amount>Maximum amount of a VTXO
required_board_confirmations: usizeThe number of confirmations required to register a board vtxo
max_user_invoice_cltv_delta: u16Maximum CLTV delta server will allow clients to request an invoice generation with.
min_board_amount: AmountMinimum amount for a board the server will cosign
offboard_feerate_sat_per_kvb: u64offboard feerate in sat per kvb
ln_receive_anti_dos_required: boolIndicates whether the Ark server requires clients to either provide a VTXO ownership proof, or a lightning receive token when preparing a lightning claim.
fees: FeeScheduleThe fee schedule outlining any fees that must be paid to interact with the Ark server.