Balance

Struct Balance 

pub struct Balance {
    pub spendable: Amount,
    pub pending_lightning_send: Amount,
    pub claimable_lightning_receive: Amount,
    pub pending_in_round: Amount,
    pub pending_board: Amount,
    pub pending_exit: Option<Amount>,
}
The different balances of a Bark wallet, broken down by state.

All amounts are in sats.

Fields

spendable: Amount

Sats that are immediately spendable, either in-round or out-of-round.

pending_lightning_send: Amount

Sats locked in an outgoing Lightning payment that has not yet settled.

claimable_lightning_receive: Amount

Sats from an incoming Lightning payment that can be claimed but have not yet been swept into a spendable VTXO.

pending_in_round: Amount

Sats locked in VTXOs forfeited for a round that has not yet completed.

pending_board: Amount

Sats in board transactions that are waiting for sufficient on-chain confirmations before becoming spendable.

pending_exit: Option<Amount>

Sats held in VTXOs whose unilateral exit chain is confirmed on-chain but which haven’t yet been drained to the onchain wallet. Equivalent to the sum of Exited VTXOs whose exit state hasn’t reached Claimed. null if the exit subsystem is unavailable.