pub struct MovementSubsystem {
pub name: String,
pub kind: String,
}Expand description
Contains information about the subsystem that created the movement as well as the purpose of the movement.
Fields
name: StringThe name of the subsystem that created and manages the movement.
kind: StringThe action responsible for registering the movement.