pub struct Offboard {
pub round: RoundId,
}Expand description
Describes a completed transition of funds from offchain to onchain collaboratively with the Ark server.
Fields
round: RoundIdThe RoundId of the round in which the offboard occurred