pub struct PendingBoardInfo {
pub funding_tx: TransactionInfo,
pub vtxos: Vec<VtxoId>,
pub amount: Amount,
pub movement_id: u32,
}Expand description
Describes a completed transition of funds from onchain to offchain.
Fields
funding_tx: TransactionInfoThe funding transaction. This is the transaction that has to be confirmed onchain for the board to succeed.
vtxos: Vec<VtxoId>The IDs of the VTXOs that were created in this board.
Currently, this is always a vector of length 1
amount: AmountThe amount of the board.
movement_id: u32The ID of the movement associated with this board.