pub struct Refresh {
pub participate_round: bool,
pub round: Option<RoundId>,
}Expand description
The output of the bark refresh command
Fields
participate_round: boolA boolean indicated if the command participated in a round. If no ark::Vtxo was refreshed this variable will be set to false and otherwise true
round: Option<RoundId>The RoundId of the round if the client participated in a round