Module package

Module package 

Structs

ChildTransactionInfo
Represents a child transaction for an exit transaction package with information about the origin of the transaction
ExitTransactionPackage
FeeInfo
Contains the data required to bump the fee for a given transaction (including ancestors).