pub struct ChildTransactionInfo {
pub info: TransactionInfo,
pub origin: ExitTxOrigin,
}Expand description
Represents a child transaction for an exit transaction package with information about the origin of the transaction
Fields
info: TransactionInfoorigin: ExitTxOriginTrait Implementations
Sourceimpl Clone for ChildTransactionInfo
impl Clone for ChildTransactionInfo
Sourcefn clone(&self) -> ChildTransactionInfo
fn clone(&self) -> ChildTransactionInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChildTransactionInfo
impl Debug for ChildTransactionInfo
Sourceimpl<'de> Deserialize<'de> for ChildTransactionInfo
impl<'de> Deserialize<'de> for ChildTransactionInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ChildTransactionInfo> for ChildTransactionInfo
impl From<ChildTransactionInfo> for ChildTransactionInfo
Sourcefn from(v: ChildTransactionInfo) -> Self
fn from(v: ChildTransactionInfo) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for ChildTransactionInfo
impl PartialEq for ChildTransactionInfo
Sourceimpl Serialize for ChildTransactionInfo
impl Serialize for ChildTransactionInfo
impl Eq for ChildTransactionInfo
impl StructuralPartialEq for ChildTransactionInfo