FeeInfo

Struct FeeInfo 

pub struct FeeInfo {
    pub fee_rate: FeeRate,
    pub total_fee: Amount,
}
Contains the data required to bump the fee for a given transaction (including ancestors).

Fields

fee_rate: FeeRate

The effective fee rate of the transaction (including unconfirmed CPFP ancestors), in sats per kvB. kvb matches the unit used elsewhere in bark-json (e.g. offboard_feerate_sat_per_kvb).

total_fee: Amount

Sum of the transaction’s own fee plus the fee of each of its unconfirmed ancestors.