Module primitives

Module primitives 

Structs

BlockRef
Reference to a block in the blockchain.
EncodedVtxo
Hex-encoded serialized VTXO.
TransactionInfo
An information struct used to pair the ID of a transaction with the full transaction for ease of use and readability for the user
UtxoInfo
Struct representing information about an Unspent Transaction Output (UTXO).
VtxoInfo
Information about a single VTXO (Virtual Transaction Output).
WalletVtxoInfo
A VTXO together with its current wallet state.

Enums

VtxoStateInfo
The current state of a VTXO in the wallet.