pub enum RoundFlowState {
DelegatedPending,
Pending,
Ongoing,
AwaitingConfirmations,
Failed,
Canceled,
}Expand description
Lifecycle phase of a round participation.
Variants
DelegatedPending
Delegated participation waiting for its round.
Pending
Interactive participation waiting for its round.
Ongoing
The interactive part is being played out with the server.
AwaitingConfirmations
The round finished and its funding tx is waiting for confirmations.
Failed
The participation failed.
Canceled
The user canceled the participation.