pub struct CreateWalletRequest {
pub ark_server: Option<String>,
pub ark_server_access_token: Option<String>,
pub chain_source: Option<ChainSourceConfig>,
pub mnemonic: Option<String>,
pub network: BarkNetwork,
pub birthday_height: Option<u32>,
pub force: bool,
}Fields
ark_server: Option<String>The Ark server to use for the wallet. Optional when a config.toml already exists in the datadir.
ark_server_access_token: Option<String>👎Deprecated since 0.2.4:
access tokens are not enforced by the server; this field will be removed
An access token for a private Ark server.
Deprecated: access tokens are no longer enforced by the server; this field will be removed in a future release.
chain_source: Option<ChainSourceConfig>The chain source to use for the wallet. Optional when a config.toml already exists in the datadir.
mnemonic: Option<String>The optional mnemonic to use for the wallet
network: BarkNetworkThe network to use for the wallet
birthday_height: Option<u32>An optional birthday height to start syncing the wallet from
force: boolProceed even if the datadir contains unexpected files