pub struct ExitStatusRequest {
pub history: Option<bool>,
pub transactions: Option<bool>,
}Fields
history: Option<bool>Whether to include the detailed history of the exit process
transactions: Option<bool>Whether to include the exit transactions and their CPFP children