pub struct FeeEstimateResponse {
pub gross_amount: Amount,
pub fee: Amount,
pub net_amount: Amount,
pub vtxos_spent: Vec<VtxoId>,
}Expand description
A fee estimate for an Ark wallet operation.
Fields
gross_amount: AmountThe total amount including fees (in satoshis)
fee: AmountThe fee portion (in satoshis)
net_amount: AmountThe amount excluding fees (in satoshis). For sends, this is the amount the recipient receives. For receives, this is the amount the user gets.
vtxos_spent: Vec<VtxoId>The VTXOs that would be spent for this operation