pub struct LightningInvoiceRequest {
pub amount_sat: u64,
}Fields
amount_sat: u64The amount to create invoice for (in satoshis). This is the amount the payee will pay but the final amount received by the client will have any server-configured LightningReceiveFees deducted.