pub struct LightningPayRequest {
pub destination: String,
pub amount_sat: Option<u64>,
pub comment: Option<String>,
}Fields
destination: StringThe invoice, offer, or lightning address to pay
amount_sat: Option<u64>The amount to send (in satoshis). Optional for bolt11 invoices with amount. This must be higher than the minimum fee laid out in server-configured LightningSendFees. The wallet must also contain enough funds to cover the amount plus any fees.
comment: Option<String>An optional comment, only supported when paying to lightning addresses