pub struct SendRequest {
pub destination: String,
pub amount_sat: Option<u64>,
pub comment: Option<String>,
}Fields
destination: StringThe destination can be an Ark address, a BOLT11-invoice, LNURL or a lightning address
amount_sat: Option<u64>The amount to send (in satoshis). Optional for bolt11 invoices. Depending on the
destination, the wallet must contain this amount plus any fees configured by the server in
FeeSchedule.
comment: Option<String>An optional comment, only supported when paying to lightning addresses