Module cli

Module cli 

Modules

onchain

Structs

ArkInfo
Balance
ExitProgressResponse
ExitProgressStatus
ExitTransactionStatus
InvoiceInfo
LightningReceiveInfo
Movement
Describes an attempted movement of offchain funds within the bark::Wallet.
MovementDestination
Describes a recipient of a movement. This could either be an external recipient in send actions or it could be the bark wallet itself.
MovementSubsystem
Contains information about the subsystem that created the movement as well as the purpose of the movement.
MovementTimestamp
Contains the times at which the movement was created, updated and completed.
OffboardResult
PendingBoardInfo
Describes a completed transition of funds from onchain to offchain.

Enums

MovementStatus
PaymentMethod
Provides a typed mechanism for describing the recipient in a MovementDestination. This is a bark-json wrapper that serializes all payment methods as strings for utoipa compatibility.
RoundStatus