ArkInfo

Struct ArkInfo 

pub struct ArkInfo {
Show 13 fields pub network: Network, pub server_pubkey: PublicKey, pub round_interval: Duration, pub nb_round_nonces: usize, pub vtxo_exit_delta: BlockDelta, pub vtxo_expiry_delta: BlockDelta, pub htlc_send_expiry_delta: BlockDelta, pub htlc_expiry_delta: BlockDelta, pub max_vtxo_amount: Option<Amount>, pub max_arkoor_depth: u16, pub required_board_confirmations: usize, pub max_user_invoice_cltv_delta: u16, pub min_board_amount: Amount,
}

Fields

network: Network

The bitcoin network the server operates on

server_pubkey: PublicKey

The Ark server pubkey

round_interval: Duration

The interval between each round

nb_round_nonces: usize

Number of nonces per round

vtxo_exit_delta: BlockDelta

Delta between exit confirmation and coins becoming spendable

vtxo_expiry_delta: BlockDelta

Expiration delta of the VTXO

htlc_send_expiry_delta: BlockDelta

The number of blocks after which an HTLC-send VTXO expires once granted.

htlc_expiry_delta: BlockDelta

The number of blocks to keep between Lightning and Ark HTLCs expiries

max_vtxo_amount: Option<Amount>

Maximum amount of a VTXO

max_arkoor_depth: u16

Maximum number of OOR transition after VTXO tree leaf

required_board_confirmations: usize

The number of confirmations required to register a board vtxo

max_user_invoice_cltv_delta: u16

Maximum CLTV delta server will allow clients to request an invoice generation with.

min_board_amount: Amount

Minimum amount for a board the server will cosign