pub struct Balance {
pub spendable: Amount,
pub pending_lightning_send: Amount,
pub claimable_lightning_receive: Amount,
pub pending_in_round: Amount,
pub pending_board: Amount,
pub pending_exit: Option<Amount>,
}Expand description
The different balances of a Bark wallet, broken down by state.
All amounts are in sats.
Fields
spendable: AmountSats that are immediately spendable, either in-round or out-of-round.
pending_lightning_send: AmountSats locked in an outgoing Lightning payment that has not yet settled.
claimable_lightning_receive: AmountSats from an incoming Lightning payment that can be claimed but have not yet been swept into a spendable VTXO.
pending_in_round: AmountSats locked in VTXOs forfeited for a round that has not yet completed.
pending_board: AmountSats in board transactions that are waiting for sufficient on-chain confirmations before becoming spendable.
pending_exit: Option<Amount>Sats held in VTXOs whose unilateral exit chain is confirmed on-chain but which
haven’t yet been drained to the onchain wallet. Equivalent to the sum of
Exited VTXOs whose exit state hasn’t reached Claimed.
null if the exit subsystem is unavailable.