pub struct LightningReceiveInfo {
pub amount: Amount,
pub payment_hash: PaymentHash,
pub payment_preimage: Preimage,
pub preimage_revealed_at: Option<DateTime<Local>>,
pub finished_at: Option<DateTime<Local>>,
pub invoice: String,
pub htlc_vtxos: Vec<WalletVtxoInfo>,
}Fields
amount: AmountThe amount of the lightning receive
payment_hash: PaymentHashThe payment hash linked to the lightning receive info
payment_preimage: PreimageThe payment preimage linked to the lightning receive info
preimage_revealed_at: Option<DateTime<Local>>The timestamp at which the preimage was revealed
finished_at: Option<DateTime<Local>>The timestamp at which the lightning receive was finished
invoice: StringThe invoice string
htlc_vtxos: Vec<WalletVtxoInfo>The HTLC VTXOs granted by the server for the lightning receive
Empty if the lightning HTLC has not yet been received by the server.