LightningReceiveInfo

Struct LightningReceiveInfo 

pub struct LightningReceiveInfo {
    pub payment_hash: PaymentHash,
    pub payment_preimage: Preimage,
    pub preimage_revealed_at: Option<DateTime<Utc>>,
    pub invoice: String,
    pub htlc_vtxos: Option<Vec<WalletVtxoInfo>>,
}

Fields

payment_hash: PaymentHash

The payment hash linked to the lightning receive info

payment_preimage: Preimage

The payment preimage linked to the lightning receive info

preimage_revealed_at: Option<DateTime<Utc>>

The timestamp at which the preimage was revealed

invoice: String

The invoice string

htlc_vtxos: Option<Vec<WalletVtxoInfo>>

The HTLC VTXOs granted by the server for the lightning receive

Only present if the lightning HTLC has been received by the server.