Structs
- Child
Transaction Info - Represents a child transaction for an exit transaction package with information about the origin of the transaction
- Exit
Transaction Package - FeeInfo
- Contains the data required to bump the fee for a given transaction (including ancestors).