Module web

Module web 

Structs

ArkAddressResponse
Bip321UriQuery
Query parameters for building a BIP 321 URI.
Bip321UriRequest
Request to build a BIP 321 unified payment URI.
Bip321UriResponse
A BIP 321 unified payment URI together with its individual destinations.
BoardRequest
ConnectedResponse
CreateWalletRequest
CreateWalletResponse
DelegatedRefreshRequest
EncodedVtxoResponse
Response for the encoded-VTXO endpoint.
ExitCancelResponse
ExitClaimAllRequest
ExitClaimResponse
ExitClaimVtxosRequest
ExitProgressRequest
ExitStartRequest
ExitStartResponse
ExitStatusRequest
FeeEstimateQuery
Query parameters for fee estimates that only require an amount.
FeeEstimateResponse
A fee estimate for an Ark wallet operation.
HistoryQuery
Query parameters for filtering wallet history by payment method.
ImportVtxoRequest
LightningInvoiceForAddressRequest
LightningInvoiceRequest
LightningPayRequest
LightningPayResponse
MailboxSyncResponse
MnemonicResponse
OffboardAllFeeEstimateQuery
Query parameters for offboard-all fee estimates.
OffboardAllRequest
OffboardFeeEstimateRequest
Request body for estimating the fee of offboarding a specific set of VTXOs.
OffboardRequestInfo
OffboardVtxosRequest
OnchainDrainRequest
OnchainFeeRatesResponse
Mempool fee rates for on-chain transactions.
OnchainSendManyRequest
OnchainSendRequest
PendingRoundInfo
RefreshRequest
RoundParticipationInfo
SendOnchainFeeEstimateQuery
Query parameters for send-onchain fee estimates.
SendOnchainRequest
SendRequest
SendResponse
TipResponse
VtxoRequestInfo
VtxosQuery
WalletDeleteRequest
WalletDeleteResponse
WalletExistsResponse

Enums

BarkNetwork
Networks bark can be used on
BitcoindAuth
ChainSourceConfig