pub struct DelegatedRefreshRequest {
pub vtxos: Vec<String>,
pub height: Option<u32>,
}Fields
vtxos: Vec<String>List of VTXO IDs to refresh. The sum of the VTXOs being refreshed must be
= P2TR_DUST. Keep in mind that fees set out in RefreshFees will be deducted from the newly created VTXO, this value must also be >= P2TR_DUST.
height: Option<u32>Optional block height to schedule the refresh at. When set, the refresh fee is priced at that height and the server includes the participation in the first round once the chain tip reaches it; when omitted, the participation is eligible for the next round.